import{
select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3'; //importing the properties from the d3
const svg = select('svg'); 

// creating width and height for the svg element
const width = +svg.attr('width');
const height = +svg.attr('height');

// giving title for line chart using render
const render = data => { 
  const title = 'OLYMPIC MEDALS WON BY USA'; 
  
  const xValue = d => +d.Year; 
  //Labelled X axis as Year
  const xAxisLabel = 'Year';

  const yValue = d => d.Medals;
  //Labelled Y axis as Medals Won
  const yAxisLabel = 'Medals Won'; 
  
  // providing the margin for line chart using css properties
  const margin = { top: 60, right: 40, bottom: 88, left: 150 }; 
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  
  const xScale = scaleTime()
  
  //returns the minimum and maximum value in an array from the given array using natural order.
    .domain(extent(data, xValue))
  //output bounds
    .range([0,innerWidth])
  // it will round the values out
    .nice();
  
  const yScale = scaleLinear() // 
    .domain([0, max(data, yValue )])
    .range([innerHeight,0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);//center g in svg
  
  // to get axis position at bottom
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight) 
    .tickPadding(20);
  
   // to get axis position at left side
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth) 
    .tickPadding(10);
  
   //It appends a 'g' element to the SVG. g element is used to group SVG shapes together
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  
  // Labeling the text
  yAxisG.append('text') 
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  //labelling for x axis
  xAxisG.append('text') 
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  // Generrates vertical and horizontal lines for x and y axis
  const lineGenerator = line() 
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d))); 
  
   // provides path to the line
  g.append('path') 
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
    console.log(lineGenerator(data))
  
 // Labeling the title
  g.append('text') 
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};
// getting the csv data uisng github url link for my line chart 
csv('https://gist.githubusercontent.com/BhanuMotupalli/9ebbe62f2deea2a3e9b97f4b9d9380a7/raw/ce79df1900a48b2bf28de3f0378da1c6ef36d8c4/Medals')
  .then(data => {
  	//console.log(data)
    data.forEach(d => {
    	d.Medals = +d.Medals;
      d.Year = new Date(d.Year)
    });
  console.log(data)
    render(data);
  });